@@ -23,6 +23,10 @@ def csvjoin_main():
         df = pandas.read_csv(os.path.expanduser(csvfile)) 
         df.to_sql(tbname, con, if_exists="replace")
 
+    pandas.set_option("max_columns",None)
+    pandas.set_option("max_rows",None)
+    pandas.options.display.width = 0
+
     df = pandas.read_sql_query(args.sql, con)
     print(df)
 
